@@ -91,11 +91,11 @@ class IO:
         # create branches for tshower
         self.__eng = np.zeros(1, dtype=float)
         self.__zen = np.zeros(1, dtype=float)
-        self.__startalt = np.zeros(1, dtype=float)
+        self.__startdist = np.zeros(1, dtype=float)
 
         self.__tshower.Branch("energy", self.__eng, 'eng/D')
         self.__tshower.Branch("zenith", self.__zen, 'zen/D')
-        self.__tshower.Branch("startalt", self.__startalt, 'startalt/D')
+        self.__tshower.Branch("startdist", self.__startdist, 'startdist/D')
 
         # define histograms
         histo_w = TH1D()
@@ -117,7 +117,7 @@ class IO:
         if self.__root:
             self.__eng[0] = energy
             self.__zen[0] = theta_D
-            self.__startalt[0] = L_particle
+            self.__startdist[0] = L_particle
             self.__tshower.Fill()
 
     def write_cher_ph_prop(self, cher_ph):
@@ -307,7 +307,7 @@ def create_config(user_args):
     cfg.optionxform = lambda option: option
     cfg['shower'] = {'energy': user_args.eng,
                      'angle': f"""{user_args.angle[0]}, {user_args.angle[1]}""",
-                     'distFistInteraction': user_args.distFirstInt}
+                     'distFirstInt': f"""{user_args.distFirstInt[0]}, {user_args.distFirstInt[1]}"""}
     cfg['detector'] = {'altitude': user_args.det_alt}
     cfg['atmosphere'] = {'scattering': user_args.atm_scatter}
     cfg['magField'] = {'useField': user_args.mag_field}
