@@ -148,7 +148,7 @@ def cherenkov_from_particle_profile(detector_altitude,
     if atmo.get('alphaFile') != '':
         extinction_coefficient_file = atmo.get('alphaFile')
     else:
-        extinction_coefficient_file = files("EASCherSim.data") / \
+        extinction_coefficient_file = files("easchersim.data") / \
             "alpha_values_typical_atmosphere_updated.txt"
     alpha = atm.atmospheric_extinction_coefficient(extinction_coefficient_file)
 
@@ -190,7 +190,7 @@ def cherenkov_from_particle_profile(detector_altitude,
         charged_parts = elef.Greisen_Longitudinal_Profile(energy, slant_depths)
     else:
         if run_set.get('protoShowerPofile') == '':
-            filename = str(files("EASCherSim.data") / "Example_CORSIKA_proton_1e17eV.long")
+            filename = str(files("easchersim.data") / "Example_CORSIKA_proton_1e17eV.long")
             simulated_energy = 1e17
         else:
             filename = run_set.get('protoShowerPofile')
